pywurfl.algorithms.Algorithm

Package pywurfl :: Module algorithms :: Class Algorithm |
[hide private]
[frames] | no frames]

# Class Algorithm

source code

    object --+
             |
            Algorithm

Known Subclasses:
  JaroWinkler, LevenshteinDistance, Tokenizer

Base class for all pywurfl search algorithms

Instance Methods | [hide private]
Device |
__call__(self, ua, devices) Every pywurfl algorithm class must define a __call__ method. | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __call__(self, ua, devices) (Call operator) | source code
Every pywurfl algorithm class must define a __call__ method. Parameters: `ua` (string) - The user agent `devices` (Devices) - The devices object to search Returns: Device